Simulate observations from the model with cumulative hazard given by $$\Lambda(t) = \lambda\cdot t^s$$ where \(\lambda\) is the rate parameter and \(s\) is the shape parameter.
rweibullcox(n, rate, shape)(integer) number of observations
(numeric) rate parameter (can be a vector of size n)
(numeric) shape parameter (can be a vector of size n)
[stats::rweibull()] uses a different parametrization with cumulative hazard given by $$H(t) = (t/b)^a,$$ i.e., the shape is the same \(a:=s\) but the scale paramter \(b\) is related to rate paramter \(r\) by $$r := b^{-a}$$
[stats::rweibull()]