Learn R Programming

mets (version 1.3.11)

IC.phreg: Influence Functions for phreg objects

Description

Computes the influence functions (IID decomposition) for the regression coefficients and/or the baseline cumulative hazard at a specific time point.

Usage

# S3 method for phreg
IC(x, type = "robust", all = FALSE, time = NULL, baseline = NULL, ...)

Value

A matrix of influence functions. If all=TRUE, columns correspond to regression coefficients and baseline cumulative hazard. Attributes include coef

and time.

Arguments

x

Object of class "phreg".

type

Type of influence function: "robust" (default) or "martingale".

all

Logical; if TRUE, returns both beta and baseline influence functions.

time

Time point for baseline influence function (required if baseline is requested).

baseline

Arguments for baseline estimation.

...

Additional arguments.

Author

Thomas Scheike

See Also

phreg, iidBaseline