Learn R Programming

mets (version 1.3.11)

binregCasewise: Estimate Casewise Concordance Using Binomial Regression

Description

Estimates the casewise concordance based on concordance and marginal estimates obtained from binreg objects. Uses cluster-based IID for standard errors, which are often better than those from casewise (which can be conservative).

Usage

binregCasewise(concbreg, margbreg, zygs = c("DZ", "MZ"), newdata = NULL, ...)

Value

A list containing:

coef

Exponentiated coefficients (ratios).

logcoef

Log-scale coefficients and standard errors.

Arguments

concbreg

Concordance object from binreg.

margbreg

Marginal estimate object from binreg.

zygs

Order of zygosity for estimation (e.g., c("DZ","MZ")).

newdata

Data frame to give instead of zygs.

...

Arguments passed to estimate.

Author

Thomas Scheike

Examples

Run this code
data(prt)
prt <- force_same_cens(prt,cause="status")

dd <- bicompriskData(Event(time, status)~strata(zyg)+id(id), data=prt, cause=c(2, 2))
newdata <- data.frame(zyg=c("DZ","MZ"),id=1)

## concordance 
bcif1 <- binreg(Event(time,status)~-1+factor(zyg)+cluster(id), data=dd,
                time=80, cause=1, cens.model=~strata(zyg))
pconc <- predict(bcif1,newdata)

## marginal estimates 
mbcif1 <- binreg(Event(time,status)~cluster(id), data=prt, time=80, cause=2)
mc <- predict(mbcif1,newdata)

cse <- binregCasewise(bcif1,mbcif1)
cse

Run the code above in your browser using DataLab