Estimates the average treatment effect \(E(Y(i,j))\) of treatment regime \((i,j)\) under two-stage randomization. The estimator can be augmented using information from both randomizations and dynamic censoring augmentation to improve efficiency.
binregTSR(
formula,
data,
cause = 1,
time = NULL,
cens.code = 0,
response.code = NULL,
augmentR0 = NULL,
treat.model0 = ~+1,
augmentR1 = NULL,
treat.model1 = ~+1,
augmentC = NULL,
cens.model = ~+1,
estpr = c(1, 1),
response.name = NULL,
offset = NULL,
weights = NULL,
cens.weights = NULL,
beta = NULL,
kaplan.meier = TRUE,
no.opt = FALSE,
method = "nr",
augmentation = NULL,
outcome = c("cif", "rmst", "rmst-cause"),
model = "exp",
Ydirect = NULL,
return.dataw = 0,
pi0 = 0.5,
pi1 = 0.5,
cens.time.fixed = 1,
outcome.iid = 1,
meanCs = 0,
...
)An object of class "binregTSR" containing:
Simple estimator results (coefficient, SE).
First randomization augmentation results.
Second randomization augmentation results.
Both randomizations augmentation results.
Influence functions for all estimators.
Variance-covariance matrices.
Censoring martingale contributions.
Censoring augmentation terms.
Dynamic censoring coefficients.
Weighted data (if return.dataw=TRUE).
Formula with outcome (see coxph), typically Event(entry,time,status)~+1+cluster(id).
Data frame containing all variables.
Cause of interest for competing risks (default 1).
Time point for estimation.
Censoring code (default 0).
Code of status indicating response at which 2nd randomization occurs.
Covariates for augmentation model of the first randomization.
Logistic treatment model for the first randomization.
Covariates for augmentation model of the second randomization.
Logistic treatment model for the second randomization.
Covariates for censoring augmentation model.
Stratification for censoring model based on observed covariates.
Logical; estimate randomization probabilities using model (default TRUE).
Name of response variable (reads from treat.model1 if NULL).
Not implemented.
Not implemented.
Can be provided externally.
Starting values for optimization.
Logical; use Kaplan-Meier for censoring weights rather than exp cumulative hazard.
Not implemented.
Not implemented.
Not implemented.
Outcome type: "cif" (cumulative incidence), "rmst" (restricted mean survival time),
or "rmst-cause" (restricted mean time lost for cause).
Not implemented, uses linear regression for augmentation.
Use this Y instead of outcome constructed inside the program.
Logical; return weighted data for all treatment regimes.
Known randomization probabilities for first randomization.
Known randomization probabilities for second randomization.
Logical; use time-dependent weights for censoring estimation.
Logical; get iid contribution from outcome model.
Logical; indicates censoring augmentation is centered by CensAugment.times/n.
Additional arguments to lower-level functions.
Thomas Scheike
The method solves the estimating equation: $$ \frac{I(\min(T_i,t) < G_i)}{G_c(\min(T_i,t))} I(T \leq t, \epsilon=1) - AUG_0 - AUG_1 + AUG_C - p(i,j) = 0 $$ where:
\(AUG_0 = \frac{A_0(i) - \pi_0(i)}{\pi_0(i)} X_0 \gamma_0\) uses covariates from augmentR0
\(AUG_1 = \frac{A_0(i)}{\pi_0(i)} \frac{A_1(j) - \pi_1(j)}{\pi_1(j)} X_1 \gamma_1\) uses covariates from augmentR1
\(AUG_C = \int_0^t \gamma_c(s)^T (e(s) - \bar e(s)) \frac{1}{G_c(s)} dM_c(s)\) is the censoring augmentation
Standard errors are estimated using the influence function of all estimators, enabling tests of differences to be computed subsequently. The method handles both survival data and competing risks data, and supports multiple treatment levels.
Scheike, T. H. (2024). Two-stage randomization analysis for survival data. mets package documentation.
binreg, phreg_rct
ddf <- mets:::gsim(200,covs=1,null=0,cens=1,ce=2)
bb <- binregTSR(Event(entry,time,status)~+1+cluster(id),ddf$datat,time=2,cause=c(1),
cens.code=0,treat.model0=A0.f~+1,treat.model1=A1.f~A0.f,
augmentR1=~X11+X12+TR,augmentR0=~X01+X02,
augmentC=~A01+A02+X01+X02+A11t+A12t+X11+X12+TR,
response.code=2)
summary(bb)
Run the code above in your browser using DataLab