Reshapes clustered long-format data to wide format efficiently using compiled code.
faster.reshape(data, clusters, index.type = FALSE, num = NULL, Rindex = 1)A wide-format matrix.
a matrix or data.frame to reshape.
vector of cluster identifiers, or column name in data.
logical; if TRUE, clusters are already 0-based indices.
optional within-cluster numbering variable.
if 1, use R (1-based) indexing.