Learn R Programming

mets (version 1.3.11)

logitSurv: Proportional Odds Survival Model

Description

Fits a semiparametric proportional odds model where: $$ \mbox{logit}(S(t|x)) = \log(\Lambda(t)) + x \beta $$ Thus, covariate effects represent the odds ratio (OR) of survival.

Usage

logitSurv(formula, data, offset = NULL, weights = NULL, ...)

Value

An object of class "phreg" with propodds=1.

Arguments

formula

Formula with 'Surv' outcome (similar to coxph).

data

Data frame.

offset

Offsets for \(\exp(x \beta)\) terms.

weights

Weights for score equations.

...

Additional arguments passed to lower-level functions.

Author

Thomas Scheike

Details

This is equivalent to using a hazards model: $$ Z \lambda(t) \exp(x \beta) $$ where \(Z\) is gamma distributed with mean and variance 1.

References

Eriksson, Frank, Li, Jianing, Scheike, Thomas, and Zhang, Mei-Jie (2015). "The proportional odds cumulative incidence model for competing risks." Biometrics, 71(3), 687--695.

Examples

Run this code
data(TRACE)
dcut(TRACE) <- ~.
out1 <- logitSurv(Surv(time, status == 9) ~ vf + chf + strata(wmicat.4), data = TRACE)
summary(out1)
gof(out1)
plot(out1)

Run the code above in your browser using DataLab