powered by
Fits a semiparametric proportional odds model where: $$ \mbox{logit}(S(t|x)) = \log(\Lambda(t)) + x \beta $$ Thus, covariate effects represent the odds ratio (OR) of survival.
logitSurv(formula, data, offset = NULL, weights = NULL, ...)
An object of class "phreg" with propodds=1.
"phreg"
propodds=1
Formula with 'Surv' outcome (similar to coxph).
coxph
Data frame.
Offsets for \(\exp(x \beta)\) terms.
Weights for score equations.
Additional arguments passed to lower-level functions.
Thomas Scheike
This is equivalent to using a hazards model: $$ Z \lambda(t) \exp(x \beta) $$ where \(Z\) is gamma distributed with mean and variance 1.
Eriksson, Frank, Li, Jianing, Scheike, Thomas, and Zhang, Mei-Jie (2015). "The proportional odds cumulative incidence model for competing risks." Biometrics, 71(3), 687--695.
data(TRACE) dcut(TRACE) <- ~. out1 <- logitSurv(Surv(time, status == 9) ~ vf + chf + strata(wmicat.4), data = TRACE) summary(out1) gof(out1) plot(out1)
Run the code above in your browser using DataLab