If times was given at call time, printing shows the stored estimate
object(s) (same as summary(x)) since that output is already compact.
Usage
# S3 method for class 'resmean_phreg'
print(x, ...)If times was given at call time, printing shows the stored estimate
object(s) (same as summary(x)) since that output is already compact.
# S3 method for class 'resmean_phreg'
print(x, ...)