Computes the ratio of two Average Treatment Effects (ATEs), typically comparing the ATE for a specific cause (e.g., RMTL due to cause 1) to the ATE for the total RMTL.
Value
A list containing:
- ratioG
Ratio based on the simple IPCW estimator.
- ratioDR
Ratio based on the double robust estimator.
Details
The function transforms the estimates (e.g., using log) to compute the ratio and its standard error using the delta method and the joint influence functions.
Examples
data(bmt); bmt$event <- bmt$cause!=0; dfactor(bmt) <- tcell~tcell
out <- resmeanATE(Event(time,event)~tcell+platelet, data=bmt, time=40, outcome="rmtl")
out1 <- resmeanATE(Event(time,cause)~tcell+platelet, data=bmt, cause=1, time=40, outcome="rmtl")
ratioATE(out, out1, h=log)