Learn R Programming

mets (version 1.3.11)

resmeanATE: Average Treatment Effect for Restricted Mean Time

Description

Estimates the Average Treatment Effect (ATE) for Restricted Mean Survival Time (RMST) or Restricted Mean Time Lost (RMTL) in censored competing risks data using IPCW.

Usage

resmeanATE(formula, data, model = "exp", outcome = c("rmst", "rmtl"), ...)

Value

An object of class "binregATE" containing:

riskG

Simple IPCW estimator results.

riskDR

Double Robust estimator results.

riskG.iid, riskDR.iid

Influence functions.

coef

Treatment effect estimates.

se

Standard errors.

Arguments

formula

Formula with an Event outcome. The first covariate must be the treatment factor.

data

Data frame.

model

Link function: "exp" (exponential) or "lin" (identity).

outcome

Outcome type: "rmst" or "rmtl".

...

Additional arguments passed to binregATE, such as time, treat.model, augmentR0, augmentC, etc.

Author

Thomas Scheike

Details

Under standard causal assumptions (Consistency, Ignorability, Positivity), the ATE is estimated as \(E(Y(1) - Y(0))\), where \(Y(a)\) is the potential outcome under treatment \(a\). The method uses double robust estimating equations that are IPCW-adjusted for censoring.

The first covariate in the formula must be the treatment effect (a factor). If the factor has more than two levels, multinomial logistic regression (mlogit) is used for propensity score modeling.

References

Scheike, T. and Holst, K. K. (2024). Restricted mean time lost for survival and competing risks data using mets in R. WIP.

Scheike, T. and Tanaka, S. (2025). Restricted mean time lost ratio regression: Percentage of restricted mean time lost due to specific cause. WIP.

See Also

binregATE, ratioATE

Examples

Run this code
data(bmt); bmt$event <- bmt$cause!=0; dfactor(bmt) <- tcell~tcell

out <- resmeanATE(Event(time,event)~tcell+platelet, data=bmt, time=40, 
                  treat.model=tcell~platelet, outcome="rmtl")
summary(out)

out1 <- resmeanATE(Event(time,cause)~tcell+platelet, data=bmt, cause=1, time=40,
                   treat.model=tcell~platelet, outcome="rmtl")
summary(out1)

Run the code above in your browser using DataLab