Simulates data from an illness-death model with two causes of death from the illness state. Covariate effects can be introduced via relative risk terms.
sim_multistateII(
cumhaz,
death.cumhaz,
death.cumhaz2,
n = NULL,
rr = NULL,
rd = NULL,
rd2 = NULL,
gamma23 = 0,
gamma24 = 0,
early2 = 10000,
gap.time = FALSE,
max.recurrent = 100,
cens = NULL,
rrc = NULL,
extend = TRUE,
...
)Data frame with multi-state event history.
Cumulative hazard from state 1 to 2.
Cumulative hazard of death from state 1.
Cumulative hazard of death from state 2.
Number of simulations.
Relative risks.
Relative risks for death from state 1.
Relative risks for death from state 2.
Early effect parameters for death causes.
Early effect parameters for death causes.
Time threshold for early effect.
Gap time indicator.
Maximum recurrent events.
Censoring specification.
Censoring relative risks.
Extend hazards.
Additional arguments.
Thomas Scheike