Restricts bivariate survival data to a rectangular time region defined by left-truncation and right-censoring boundaries, for use with piecewise twostage models.
surv_boxarea(
left.trunc,
right.cens,
data,
timevar = "time",
status = "status",
id = "id",
covars = NULL,
covars.pairs = NULL,
num = NULL,
silent = 1,
boxtimevar = "boxtime"
)A data.frame in long format restricted to the specified region.
vector of length 2 giving left truncation times.
vector of length 2 giving right censoring times.
a data.frame with the survival data.
name of the time variable.
name of the status variable.
name of the cluster identifier.
optional covariate names.
optional pair-level covariate names.
within-cluster numbering variable name.
verbosity level (1=silent).
name for the created box-time variable.