Helper functions for the twostage survival dependence models.
survival.twostage(x, ...)matplot.mets.twostage(object, ...)
alpha2spear(theta, link = 1)
alpha2kendall(theta, link = 0)
piecewise_twostage(
cut1,
cut2,
data = parent.frame(),
timevar = "time",
status = "status",
id = "id",
covars = NULL,
covars.pairs = NULL,
num = NULL,
method = "optimize",
Nit = 100,
detail = 0,
silent = 1,
weights = NULL,
control = list(),
theta = NULL,
theta.des = NULL,
var.link = 1,
step = 0.5,
model = "plackett",
data.return = 0
)
piecewise_data(
cut1,
cut2,
data = parent.frame(),
timevar = "time",
status = "status",
id = "id",
covars = NULL,
covars.pairs = NULL,
num = NULL,
silent = 1
)
a marginal model object (for survival.twostage).
additional arguments.
a twostage model object (for matplot method).
initial dependence parameter values.
if 1, parameters are on log scale (for alpha2kendall/alpha2spear).
vector of cut points for the first time axis.
vector of cut points for the second time axis.
a data.frame with the survival data.
character name of the time variable.
character name of the status variable.
name of the cluster identifier column.
optional character vector of covariate names.
optional covariates at the pair level.
character name of the within-cluster number variable.
optimization method.
maximum number of iterations.
level of detail in output.
level of verbosity (1=silent).
optional weights.
optimization control list.
theta design matrix.
if 1, log-link for variance parameters.
step size for optimization.
dependence model: "plackett" or "clayton.oakes".
if 1, return data with model fits.
Klaus K. Holst, Thomas Scheike
survival.twostage is an alias for survival_twostage.
alpha2kendall converts the Clayton-Oakes alpha parameter to Kendall's tau.
alpha2spear converts the Clayton-Oakes alpha parameter to Spearman's rho.
piecewise_twostage fits twostage models on piecewise time intervals.
piecewise_data prepares data for piecewise twostage analysis.
matplot.mets.twostage produces matplot of twostage baseline estimates.